@@ -310,12 +310,12 @@ class Sherlock:
                 self.report[sherlock_id].append(object_report)
                 self.__setup_object_report_logging(sherlock_id, True)
                 logging.info("Listing most promising candidates for ID %s:", sherlock_id)
-                logging.info("%-12s%-10s%-10s%-10s%-8s%-8s%-8s%-8s%-10s%-14s%-14s%-12s%-25s%-10s%-18s%-20s", "Detrend no.", "Period",
-                             "Per_err", "Duration", "T0", "Depth", "SNR", "SDE", "FAP", "Border_score", "Matching OI", "Harmonic",
+                logging.info("%-12s%-10s%-10s%-10s%-8s%-8s%-8s%-8s%-14s%-14s%-12s%-25s%-10s%-18s%-20s", "Detrend no.", "Period",
+                             "Per_err", "Duration", "T0", "Depth", "SNR", "SDE", "Border_score", "Matching OI", "Harmonic",
                              "Planet radius (R_Earth)", "Rp/Rs", "Semi-major axis", "Habitability Zone")
                 if sherlock_id in self.report:
                     candidates_df = pandas.DataFrame(columns=['curve', 'period', 'per_err', 'duration', 't0', 'depth',
-                                                              'snr', 'sde', 'fap', 'border_score', 'oi', 'rad_p', 'rp_rs',
+                                                              'snr', 'sde', 'border_score', 'oi', 'rad_p', 'rp_rs',
                                                               'a', 'hz'])
                     i = 1
                     for report in self.report[sherlock_id]:
@@ -328,10 +328,10 @@ class Sherlock:
                             report['rad_p'] = np.nan
                         else:
                             report['rad_p'] = self.__calculate_planet_radius(lc_build.star_info, report["depth"])
-                        logging.info("%-12s%-10.4f%-10.5f%-10.2f%-8.2f%-8.3f%-8.2f%-8.2f%-10.6f%-14.2f%-14s%-12s%-25.5f%-10.5f%-18.5f%-20s",
+                        logging.info("%-12s%-10.4f%-10.5f%-10.2f%-8.2f%-8.3f%-8.2f%-8.2f%-14.2f%-14s%-12s%-25.5f%-10.5f%-18.5f%-20s",
                                      report["curve"], report["period"], report["per_err"],
                                      report["duration"], report["t0"], report["depth"], report["snr"], report["sde"],
-                                     report["fap"], report["border_score"], report["oi"], report["harmonic"],
+                                     report["border_score"], report["oi"], report["harmonic"],
                                      report['rad_p'], report['rp_rs'], a, habitability_zone)
                         candidates_df = candidates_df.append(report, ignore_index=True)
                         i = i + 1
@@ -395,7 +395,7 @@ class Sherlock:
         logger = logging.getLogger()
         while len(logger.handlers) > 1:
             logger.handlers.pop()
-        formatter = logging.Formatter(fmt='%(message)s', datefmt='%Y-%m-%d %H:%M:%S')
+        formatter = logging.Formatter()
         handler = logging.FileHandler(object_dir + str(object_id) + "_report.log")
         handler.setLevel(logging.INFO)
         handler.setFormatter(formatter)
@@ -406,7 +406,7 @@ class Sherlock:
         object_dir = self.__setup_object_logging(object_id, False)
         logger = logging.getLogger()
         logger.handlers.pop()
-        formatter = logging.Formatter(datefmt='%Y-%m-%d %H:%M:%S')
+        formatter = logging.Formatter()
         file = object_dir + str(object_id) + "_candidates.log"
         if clean and os.path.exists(file):
             os.remove(file)
@@ -554,7 +554,7 @@ class Sherlock:
                 format(signal_selection.transit_result.duration * 24 * 60, '.0f') + 'm # SNR:' + \
                 str(format(signal_selection.transit_result.snr, '.2f')) + ' # SDE:' + \
                 str(format(signal_selection.transit_result.sde, '.2f'))
-        file = 'Run_' + str(id_run) + '_SELECTED_' + str(star_info.object_id) + '.png'
+        file = 'Run_' + str(id_run) + '_SELECTED_' + str(signal_selection.curve_index) + '_' + str(star_info.object_id) + '.png'
         save_transit_plot(star_info.object_id, title, run_dir, file, time, lcs[signal_selection.curve_index],
                           signal_selection.transit_result, cadence, id_run)
         if sherlock_target.pickle_mode == 'all':
@@ -662,9 +662,9 @@ class Sherlock:
                            cadence, report, period_grid, detrend_source_period):
         object_info = sherlock_target.object_info
         detrend_logging_customs = 'ker_size' if sherlock_target.detrend_method == 'gp' else "win_size"
-        logging.info("%-12s%-12s%-10s%-8s%-18s%-14s%-14s%-12s%-12s%-14s%-16s%-14s%-12s%-25s%-10s%-18s%-20s",
+        logging.info("%-12s%-12s%-10s%-8s%-18s%-14s%-14s%-12s%-12s%-16s%-14s%-12s%-25s%-10s%-18s%-20s",
                      detrend_logging_customs, "Period", "Per_err", "N.Tran", "Mean Depth (ppt)", "T. dur (min)", "T0",
-                     "SNR", "SDE", "FAP", "Border_score", "Matching OI", "Harmonic", "Planet radius (R_Earth)", "Rp/Rs",
+                     "SNR", "SDE", "Border_score", "Matching OI", "Harmonic", "Planet radius (R_Earth)", "Rp/Rs",
                      "Semi-major axis", "Habitability Zone")
         transit_results = {}
         plot_dir = self.__init_object_run_dir(star_info.object_id, id_run)
@@ -676,11 +676,11 @@ class Sherlock:
             a, habitability_zone = self.habitability_calculator \
                 .calculate_hz_score(star_info.teff, star_info.mass, star_info.lum, transit_result.period)
             oi = self.__find_matching_oi(object_info, transit_result.period)
-            logging.info('%-12s%-12.5f%-10.6f%-8s%-18.3f%-14.1f%-14.4f%-12.3f%-12.3f%-14s%-16.2f%-14s%-12s%-25.5f%-10.5f%-18.5f%-20s',
+            logging.info('%-12s%-12.5f%-10.6f%-8s%-18.3f%-14.1f%-14.4f%-12.3f%-12.3f%-16.2f%-14s%-12s%-25.5f%-10.5f%-18.5f%-20s',
                          "PDCSAP_FLUX", transit_result.period,
                          transit_result.per_err, transit_result.count, transit_result.depth,
                          transit_result.duration * 24 * 60, transit_result.t0, transit_result.snr, transit_result.sde,
-                         transit_result.fap, transit_result.border_score, oi, transit_result.harmonic, r_planet, rp_rs, a,
+                         transit_result.border_score, oi, transit_result.harmonic, r_planet, rp_rs, a,
                          habitability_zone)
             plot_title = 'Run ' + str(id_run) + 'PDCSAP_FLUX # P=' + \
                          format(transit_result.period, '.2f') + 'd # T0=' + format(transit_result.t0, '.2f') + \
@@ -702,11 +702,11 @@ class Sherlock:
             a, habitability_zone = self.habitability_calculator \
                 .calculate_hz_score(star_info.teff, star_info.mass, star_info.lum, transit_result.period)
             oi = self.__find_matching_oi(object_info, transit_result.period)
-            logging.info('%-12.4f%-12.5f%-10.6f%-8s%-18.3f%-14.1f%-14.4f%-12.3f%-12.3f%-14s%-16.2f%-14s%-12s%-25.5f%-10.5f%-18.5f%-20s',
+            logging.info('%-12.4f%-12.5f%-10.6f%-8s%-18.3f%-14.1f%-14.4f%-12.3f%-12.3f%-16.2f%-14s%-12s%-25.5f%-10.5f%-18.5f%-20s',
                          wl[i], transit_result.period,
                      transit_result.per_err, transit_result.count, transit_result.depth,
                      transit_result.duration * 24 * 60, transit_result.t0, transit_result.snr, transit_result.sde,
-                     transit_result.fap, transit_result.border_score, oi, transit_result.harmonic, r_planet, rp_rs, a,
+                         transit_result.border_score, oi, transit_result.harmonic, r_planet, rp_rs, a,
                      habitability_zone)
             detrend_file_title_customs = 'ker_size' if sherlock_target.detrend_method == 'gp' else 'win_size'
             detrend_file_name_customs = 'ks' if sherlock_target.detrend_method == 'gp' else 'ws'
